/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a kf5authadaptor -i backends/dbus/DBusHelperProxy.h -l KAuth::DBusHelperProxy /usr/src/ports/kf5-kauth/kf5-kauth-5.43.0-1.x86_64/src/kauth-5.43.0/src/backends/dbus/org.kde.kf5auth.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kf5authadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class Kf5authAdaptor
 */

Kf5authAdaptor::Kf5authAdaptor(KAuth::DBusHelperProxy *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

Kf5authAdaptor::~Kf5authAdaptor()
{
    // destructor
}

QByteArray Kf5authAdaptor::performAction(const QString &action, const QByteArray &callerID, const QByteArray &arguments)
{
    // handle method call org.kde.kf5auth.performAction
    return parent()->performAction(action, callerID, arguments);
}

void Kf5authAdaptor::stopAction(const QString &action)
{
    // handle method call org.kde.kf5auth.stopAction
    parent()->stopAction(action);
}


#include "kf5authadaptor.moc"
