// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kauthdebug.h"


#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
Q_LOGGING_CATEGORY(KAUTH, "kf5.kauth", QtInfoMsg)
#else
Q_LOGGING_CATEGORY(KAUTH, "kf5.kauth")
#endif

